@@ -1,9 +1,10 @@
 from sklearn.utils import check_random_state
-from sklearn.utils.fixes import sp_version
 from .space import Real, Integer, Categorical, Space
 import numpy as np
+
+
 class Constraints:
-    def __init__(self, constraints_list,space):
+    def __init__(self, constraints_list, space):
         """Constraints used when sampling for the aqcuisiiton function
 
         Parameters
@@ -15,39 +16,43 @@ class Constraints:
             A Space object.
         """
 
-        if not isinstance(space,Space):
+        if not isinstance(space, Space):
             space = Space(space)
-        check_constraints(space,constraints_list) # Check that all constraints are valid
+        # Check that all constraints are valid:
+        check_constraints(space, constraints_list)
         self.space = space
-        # Lists that keep track of which dimensions has which constraints 
+        # Lists that keep track of which dimensions has which constraints:
         self.single = [None for _ in range(space.n_dims)]
         self.inclusive = [[] for _ in range(space.n_dims)]
         self.exclusive = [[] for _ in range(space.n_dims)]
         self.sum = []
         self.conditional = []
-        self.constraints_list = constraints_list # A copy of the list of constraints
+        # A copy of the list of constraints:
+        self.constraints_list = constraints_list
         # Append constraints to the lists
         for constraint in constraints_list:
-            if isinstance(constraint,Single):
-               self.single[constraint.dimension] = constraint
-            elif isinstance(constraint,Inclusive):
+            if isinstance(constraint, Single):
+                self.single[constraint.dimension] = constraint
+            elif isinstance(constraint, Inclusive):
                 self.inclusive[constraint.dimension].append(constraint)
-            elif isinstance(constraint,Exclusive):
+            elif isinstance(constraint, Exclusive):
                 self.exclusive[constraint.dimension].append(constraint)
-            elif isinstance(constraint,Sum):
+            elif isinstance(constraint, Sum):
                 self.sum.append(constraint)
-            elif isinstance(constraint,Conditional):
+            elif isinstance(constraint, Conditional):
                 self.conditional.append(constraint)
             else:
-                raise TypeError('Constraint type {} is not recognized'.format(type(constraint)))
+                raise TypeError(
+                    'Constraint type {} is not recognized'.format(
+                        type(constraint)))
 
     def __eq__(self, other):
-        if isinstance(other,Constraints):
+        if isinstance(other, Constraints):
             return self.constraints_list == other.constraints_list
         else:
             return False
 
-    def rvs(self, n_samples = 1, random_state = None):
+    def rvs(self, n_samples=1, random_state=None):
         """Draw random samples that all are valid with regards to the constraints.
 
         The samples are in the original space. They need to be transformed
@@ -69,20 +74,29 @@ class Constraints:
         """
 
         rng = check_random_state(random_state)
-        rows  = [] # A list of the samples drawn
-        n_samples_candidates = 0 # Number of candidates for samples that have been checked
+        # A list of the samples drawn:
+        rows = []
+        # Number of candidates for samples that have been checked:
+        n_samples_candidates = 0
 
-        while len(rows) < n_samples: # We keep sampling until all samples a valid with regard to the constraints
+        # We keep sampling until all samples a valid with regard to the
+        # constraints:
+        while len(rows) < n_samples:
             columns = []
-            for i in range(self.space.n_dims): # Iterate through all dimensions
+            # Iterate through all dimensions:
+            for i in range(self.space.n_dims):
                 dim = self.space.dimensions[i]
-                if self.single[i]: # If a dimension has a "Single"-type constraint we just sample that value
+                # If a dimension has a "Single"-type constraint we just sample
+                # that value:
+                if self.single[i]:
                     column = np.full(n_samples, self.single[i].value)
-                else: # Using the default rvs() for the given dimension
-                    if sp_version < (0, 16):
-                        column = (dim.rvs(n_samples=n_samples))
-                    else:
-                        column = (dim.rvs(n_samples=n_samples, random_state=rng))
+                else:  # Using the default rvs() for the given dimension
+                    try:
+                        column = (dim.rvs(n_samples=n_samples, 
+                                          random_state=rng))
+                    except Exception as error:
+                        print(f'''Caught an error while making random points in
+                         constrained space, error is: {error}''')
                 columns.append(column)
 
             # Transpose
@@ -90,20 +104,27 @@ class Constraints:
                 r = []
                 for j in range(self.space.n_dims):
                     r.append(columns[j][i])
-                if self.validate_sample(r): # For each individual sample we check that it is valid
+                # For each individual sample we check that it is valid:
+                if self.validate_sample(r):
                     # We only append if it is valid
                     rows.append(r)
 
             n_samples_candidates += n_samples
             if n_samples_candidates > 100000 and len(rows) < 100:
-                # If we have less than a 1/10.000 succes rate on the sampling we throw an error
-                raise RuntimeError('Could not find valid samples in constrained space. Please check that the constraints allows for valid samples to be drawn')
+                # If we have less than a 1/10.000 succes rate on the sampling
+                # we throw an error
+                raise RuntimeError(
+                    '''Could not find valid samples in constrained space.
+                    Please check that the constraints allows for valid samples
+                    to be drawn''')
 
-        # We draw more samples when needed so we only return n_samples of the samples
+        # We draw more samples when needed so we only return n_samples of the
+        # samples
         return rows[:n_samples]
 
-    def validate_sample(self,sample):
-        """ Validates a sample of parameter values in regards to the constraints.
+    def validate_sample(self, sample):
+        """ Validates a sample of parameter values in regards to the
+        constraints.
 
         Parameters
         ----------
@@ -115,20 +136,25 @@ class Constraints:
         * `is_valid`: [bool]
            Returns True for valid samples and False for non-valid samples
         """
-       
-        # We iterate through all the dimensions and check the the type of constriants that are applied
-        # to a single dimensions, i.e Single, Exlcusive and Inclusive
-        for dim in range(len(sample)): # We iterate through all samples which corresponds to number of dimensions.
-            
+
+        # We iterate through all the dimensions and check the the type of
+        # constriants that are applied to a single dimensions, i.e Single,
+        # Exclusive and Inclusive
+        #
+        # We iterate through all samples which corresponds to number of
+        # dimensions:
+        for dim in range(len(sample)):
             # Single constraints.
             if self.single[dim]:
                 if not self.single[dim].validate_constraint(sample[dim]):
                     return False
 
             # Inclusive constraints.
-            if self.inclusive[dim]: # Check if there is a least one inclusive constraint.
-                # We go through all inlcusive constraints for this dimension and if the value is not found to be included in any
-                # of the bounds of the inclusive constraints we return false.
+            # Check if there is a least one inclusive constraint:
+            if self.inclusive[dim]:
+                # We go through all inlcusive constraints for this dimension
+                # and if the value is not found to be included in any of the
+                # bounds of the inclusive constraints we return false.
                 value_is_valid = False
                 for constraint in self.inclusive[dim]:
                     if constraint.validate_constraint(sample[dim]):
@@ -139,11 +165,11 @@ class Constraints:
 
             # Exclusive constraints
             for constraint in self.exclusive[dim]:
-                # The first time a value is inside of the excluded bounds of the exclusive constraint we return false.
+                # The first time a value is inside of the excluded bounds of
+                # the exclusive constraint we return false.
                 if not constraint.validate_constraint(sample[dim]):
                     return False
 
-        
         # We iterate through sum constriants
         for constraint in self.sum:
             if not constraint.validate_sample(sample):
@@ -152,17 +178,20 @@ class Constraints:
         for constraint in self.conditional:
             if not constraint.validate_sample(sample):
                 return False
-        # If we we did not find any violaiton of the constraints we return True.
+        # If we we did not find any violaiton of the constraints we return
+        # True.
         return True
 
     def __repr__(self):
         return "Constraints({})".format(self.constraints_list)
 
+
 class Single:
     def __init__(self, dimension, value, dimension_type):
         """Constraint class of type Single.
 
-        This constraint enforces that all values drawn for the specified dimension equals `value`
+        This constraint enforces that all values drawn for the specified
+        dimension equals `value`
 
         Parameters
         ----------
@@ -179,7 +208,12 @@ class Single:
 
         # Validating input parameters
         if dimension_type == 'categorical':
-            if not (type(value) == int or type(value) == str or type(value) == float):
+            if not (
+                    type(value) == int
+                    or
+                    type(value) == str
+                    or
+                    type(value) == float):
                 raise TypeError('Single categorical constraint must be of type int, float or str. Got {}'.format(type(value)))
         elif dimension_type == 'integer':
             if not type(value) == int:
@@ -191,7 +225,7 @@ class Single:
             raise ValueError('`dimension_type` must be a string containing "categorical", "integer" or "real". got {}'.format(dimension_type))
         if not (type(dimension) == int):
             raise TypeError('Constraint dimension must be of type int. Got type {}'.format(type(dimension)))
-        if not dimension >=0:
+        if not dimension >= 0:
             raise ValueError('Dimension can not be a negative number')
 
         self.value = value
@@ -215,11 +249,12 @@ class Single:
         return "Single(dimension={}, value={}, dimension_type={})".format(self.dimension, self.value, self.dimension_type)
 
     def __eq__(self, other):
-        if isinstance(other,Single):
+        if isinstance(other, Single):
             return self.value == other.value and self.dimension == other.dimension and self.dimension_type == other.dimension_type
         else:
             return False
 
+
 class Bound_constraint():
     def __init__(self, dimension, bounds, dimension_type):
         """Base class for Exclusive and Inclusive constraints"""
@@ -227,7 +262,7 @@ class Bound_constraint():
         # Validating input parameters
         if not type(bounds) == tuple and not type(bounds) == list:
             raise TypeError('Bounds should be a tuple or a list. Got {}'.format(type(bounds)))
-        if not len(bounds) >1:
+        if not len(bounds) > 1:
             raise ValueError('Bounds should be a tuple or list of length > 1.')
         if not dimension_type == 'categorical':
             if not len(bounds) == 2:
@@ -235,29 +270,31 @@ class Bound_constraint():
         for bound in bounds:
             if dimension_type == 'integer':
                 if not type(bound) == int:
-                   raise TypeError('Bounds must be of type int for integer dimension. Got {}'.format(type(bound)))
+                    raise TypeError('Bounds must be of type int for integer dimension. Got {}'.format(type(bound)))
             elif dimension_type == 'real':
                 if not type(bound) == float:
-                   raise TypeError('Bounds must be of type float for real dimension. Got {}'.format(type(bound)))
+                    raise TypeError('Bounds must be of type float for real dimension. Got {}'.format(type(bound)))
         if not (dimension_type == 'categorical' or dimension_type == 'integer' or dimension_type == 'real'):
             raise ValueError('`dimension_type` must be a string containing "categorical", "integer" or "real". Got {}'.format(dimension_type))
         if not (type(dimension) == int):
             raise TypeError('Constraint dimension must be of type int. Got type {}'.format(type(dimension)))
-        if not dimension >=0:
+        if not dimension >= 0:
             raise ValueError('Dimension can not be a negative number')
 
-        self.bounds = tuple(bounds) # Convert bounds to a tuple
+        self.bounds = tuple(bounds)  # Convert bounds to a tuple
         self.dimension = dimension
         self.dimension_type = dimension_type
 
+
 class Inclusive(Bound_constraint):
-    def __init__(self, dimension, bounds,dimension_type):
-        super().__init__(dimension, bounds, dimension_type) 
+    def __init__(self, dimension, bounds, dimension_type):
+        super().__init__(dimension, bounds, dimension_type)
         """Constraint class of type Inclusive.
 
-        This constraint enforces that all values drawn for the specified dimension are inside the bounds,
-        with the bound values included.
-        In case of categorical dimensions the constraint enforces that only values specified in bounds can be drawn.
+        This constraint enforces that all values drawn for the specified
+        dimension are inside the bounds, with the bound values included. In
+        case of categorical dimensions the constraint enforces that only values
+        specified in bounds can be drawn.
 
         Parameters
         ----------
@@ -266,12 +303,16 @@ class Inclusive(Bound_constraint):
 
         * `bounds` [tuple]:
             The bounds for the constraint.
-            For 'real' dimensions the tuple must be of length 2 and only consist of integers.
+            For 'real' dimensions the tuple must be of length 2 and only
+            consist of integers.
 
-            For 'integer' dimensions the tuple must be of length 2 and only consist of floats.
+            For 'integer' dimensions the tuple must be of length 2 and only
+            consist of floats.
 
-            For 'categorical' dimensions the tuple must be of length < number of dimensions and lenght > 1.
-                The tuple can contain any combination of str, int or float
+            For 'categorical' dimensions the tuple must be of length < number
+            of dimensions and lenght > 1.
+
+            The tuple can contain any combination of str, int or float
 
         * `dimension_type` [str]:
             The type of dimension. Can be 'integer','real' or 'categorical.
@@ -286,7 +327,8 @@ class Inclusive(Bound_constraint):
         self.validate_sample = self._validate_sample
 
     def _validate_sample(self, sample):
-        # Checks if a sample violates the constraints. Returns True if the dont.
+        # Checks if a sample violates the constraints.
+        # Returns True if it does not.
         return self.validate_constraint(sample[self.dimension])
 
     def _validate_constraint_categorical(self, value):
@@ -310,14 +352,16 @@ class Inclusive(Bound_constraint):
         else:
             return False
 
+
 class Exclusive(Bound_constraint):
     def __init__(self, dimension, bounds, dimension_type):
-        super().__init__(dimension, bounds, dimension_type) 
+        super().__init__(dimension, bounds, dimension_type)
         """Constraint class of type Inclusive.
 
-        This constraint enforces that all values drawn for the specified dimension are outside the bounds,
-        with the bound values excluded.
-        In case of categorical dimensions the constraint enforces that values specified in bounds can not be drawn.
+        This constraint enforces that all values drawn for the specified
+        dimension are outside the bounds, with the bound values excluded. In
+        case of categorical dimensions the constraint enforces that values
+        specified in bounds can not be drawn.
 
         Parameters
         ----------
@@ -326,12 +370,16 @@ class Exclusive(Bound_constraint):
 
         * `bounds` [tuple]:
             The bounds for the constraint.
-            For 'real' dimensions the tuple must be of length 2 and only consist of integers.
+            For 'real' dimensions the tuple must be of length 2 and only
+            consist of integers.
 
-            For 'integer' dimensions the tuple must be of length 2 and only consist of floats.
+            For 'integer' dimensions the tuple must be of length 2 and only
+            consist of floats.
 
-            For 'categorical' dimensions the tuple must be of length < number of dimensions and lenght > 1.
-                The tuple can contain any combination of str, int or float
+            For 'categorical' dimensions the tuple must be of length < number
+            of dimensions and lenght > 1.
+
+            The tuple can contain any combination of str, int or float
 
         * `dimension_type` [str]:
             The type of dimension. Can be 'integer','real' or 'categorical.
@@ -370,24 +418,27 @@ class Exclusive(Bound_constraint):
         else:
             return False
 
+
 class Sum():
-    def __init__(self, dimensions, value, less_than = True):
+    def __init__(self, dimensions, value, less_than=True):
         """Constraint class of type Sum.
 
-        This constraint enforces that the sum of all values drawn for the specified dimensions, is less_than or equal to a value.
-        Can only be used with integer or real dimensions.
+        This constraint enforces that the sum of all values drawn for the
+        specified dimensions, is less_than or equal to a value. Can only be
+        used with integer or real dimensions.
 
         Parameters
         ----------
         * `dimensions` [list of ints]:
-            A list of integers coresponding to the index of the dimensions that should be summed
+            A list of integers coresponding to the index of the dimensions that
+            should be summed
 
         * `value` [float or int]:
             The value for which the sum should be less than or equal to.
 
         * `less_than` [bool, default=True]:
-            If true then the sum should be less than or equal to the value. If False the sum should 
-            be greater than or equal to the value.
+            If true then the sum should be less than or equal to the value. If
+            False the sum should be greater than or equal to the value.
         """
 
         if not (type(dimensions) == tuple or type(dimensions) == list):
@@ -412,10 +463,9 @@ class Sum():
     def _validate_sample(self, sample):
         # Returns True if sample does not violate the constraints.
         if self.less_than:
-            return np.sum([sample[dim] for dim in self.dimensions])<=self.value
+            return np.sum([sample[dim] for dim in self.dimensions]) <= self.value
         else:
-            return np.sum([sample[dim] for dim in self.dimensions])>=self.value
-
+            return np.sum([sample[dim] for dim in self.dimensions]) >= self.value
 
     def __repr__(self):
         return "Sum(dimensions={}, value={}, less_than={})".format(self.dimensions, self.value, self.less_than)
@@ -426,13 +476,14 @@ class Sum():
         else:
             return False
 
+
 class Conditional():
-    def __init__(self, condition, if_true = None, if_false = None):
+    def __init__(self, condition, if_true=None, if_false=None):
         ''' Constraint class of type Conditional
-        
-        This constraint enforces other constraints depending on the 'condition'.
-        If condition is satisfied the if_true constraint is applied. If not then the if_false
-        constraint is applied.
+
+        This constraint enforces other constraints depending on the
+        'condition'. If condition is satisfied the if_true constraint is
+        applied. If not then the if_false constraint is applied.
 
         Parameters
         ----------
@@ -441,13 +492,15 @@ class Conditional():
             Condition can not be a Conditional constraint.
 
         * `if_true` [Constraint or tuple/list of constraints, deault=None]:
-            If the constraint from the condition-argument is satisfied then this constraint is applied.
+            If the constraint from the condition-argument is satisfied then
+            this constraint is applied.
 
         * `if_false` [Constraint or tuple/list of constraints, deault=None]:
-            If the constraint from the condition-argument is not satisfied then this constraint is applied.
+            If the constraint from the condition-argument is not satisfied then
+            this constraint is applied.
         '''
 
-        if isinstance(condition,Conditional):
+        if isinstance(condition, Conditional):
             raise TypeError('Condition can not be a conditional constraint')
         check_is_constraint(condition)
         if if_true:
@@ -479,18 +532,19 @@ class Conditional():
         self.if_false = if_false
         self.validate_sample = self._validate_sample
 
-    def _validate_sample(self,sample):
+    def _validate_sample(self, sample):
         # Returns True if sample does not violate the constraints.
         if self.condition.validate_sample(sample):
             # Condition evaluates to true
             if self.if_true:
-                for constraint in self.if_true: # Iterate through all constrains in if_true
+                # Iterate through all constrains in if_true:
+                for constraint in self.if_true:
                     if not constraint.validate_sample(sample):
                         # The first time a constraint fails we return False
                         return False
                 # If no constraints failed we return True
                 return True
-            else: # If there is no constraints we return True
+            else:  # If there is no constraints we return True
                 return True
         else:
             if self.if_false:
@@ -510,9 +564,10 @@ class Conditional():
         else:
             return False
 
-def check_constraints(space,constraints):
-    """ Checks if list of constraints is valid when compared with the dimensions of space.
-        Throws errors otherwise.
+
+def check_constraints(space, constraints):
+    """ Checks if list of constraints is valid when compared with the
+    dimensions of space. Throws errors otherwise.
 
         Parameters
         ----------
@@ -527,64 +582,67 @@ def check_constraints(space,constraints):
         raise TypeError('Constraints must be a list of constraints. Got {}'.format(type(constraints)))
     n_dims = space.n_dims
 
-    single_constraints = [False]*n_dims
+    single_constraints = [False] * n_dims
     for constraint in constraints:
 
-        # Check if constraints are inside bounds of space and if more than one single constraint has been
-        # applied to the same dimension
-        if isinstance(constraint,Single):
-            check_dim_and_space(space,constraint)
+        # Check if constraints are inside bounds of space and if more than one
+        # single constraint has been applied to the same dimension
+        if isinstance(constraint, Single):
+            check_dim_and_space(space, constraint)
             ind_dim = constraint.dimension
-            if single_constraints[ind_dim] == True:
+            if single_constraints[ind_dim] is True:
                 raise IndexError('Can not add more than one Singe-type constraint to dimension {}'.format(ind_dim))
             single_constraints[ind_dim] = True
             space_dim = space.dimensions[constraint.dimension]
-            check_value(space_dim,constraint.value)
-        elif isinstance(constraint,Inclusive) or isinstance(constraint,Exclusive):
-            check_dim_and_space(space,constraint)
+            check_value(space_dim, constraint.value)
+        elif isinstance(constraint, Inclusive) or isinstance(constraint, Exclusive):
+            check_dim_and_space(space, constraint)
             space_dim = space.dimensions[constraint.dimension]
-            check_bounds(space_dim,constraint.bounds)
-        elif isinstance(constraint,Sum):
+            check_bounds(space_dim, constraint.bounds)
+        elif isinstance(constraint, Sum):
             if not all(dim < n_dims for dim in constraint.dimensions):
                 raise IndexError('Dimension index exceeds number of dimensions')
             for ind_dim in constraint.dimensions:
-                if isinstance(space.dimensions[ind_dim],Categorical):
+                if isinstance(space.dimensions[ind_dim], Categorical):
                     raise ValueError('Sum constraint can not be applid to categorical dimension: {}'.format(space.dimensions[ind_dim]))
-        elif isinstance(constraint,Conditional):
-            # We run check_constraints on each constraint instance in the conditional constraint.
-            # We only check them if they are not None
-            if constraint.condition: check_constraints(space,[constraint.condition])
-            if constraint.if_true: 
+        elif isinstance(constraint, Conditional):
+            # We run check_constraints on each constraint instance in the
+            # conditional constraint. We only check them if they are not None
+            if constraint.condition:
+                check_constraints(space, [constraint.condition])
+            if constraint.if_true:
                 # Check all constraints in the if_true tuple
                 for constraint_if_true in constraint.if_true:
-                    check_constraints(space,[constraint_if_true])
+                    check_constraints(space, [constraint_if_true])
             if constraint.if_false:
                 for constraint_if_false in constraint.if_false:
-                    check_constraints(space,[constraint_if_false])
+                    check_constraints(space, [constraint_if_false])
         else:
             raise TypeError('Constraints must be of type "Single", "Exlusive", "Inclusive", "Sum" or "Conditional". Got {}'.format(type(constraint)))
 
-def check_dim_and_space(space,constraint):
+
+def check_dim_and_space(space, constraint):
     n_dims = space.n_dims
-    ind_dim = constraint.dimension # Index of the dimension
+    ind_dim = constraint.dimension  # Index of the dimension
     if not ind_dim < n_dims:
-        raise IndexError('Dimension index {} out of range for n_dims = {}'.format(ind_dim,n_dims))
+        raise IndexError('Dimension index {} out of range for n_dims = {}'.format(ind_dim, n_dims))
     space_dim = space.dimensions[constraint.dimension]
 
     # Check if space dimensions types are the same as constraint dimension types
-    if isinstance(space_dim,Real):
+    if isinstance(space_dim, Real):
         if not constraint.dimension_type == 'real':
-            raise TypeError('Constraint for real dimension {} must be of dimension_type real. Got {}'.format(ind_dim,constraint.dimension_type))
-    elif isinstance(space_dim,Integer):
+            raise TypeError('Constraint for real dimension {} must be of dimension_type real. Got {}'.format(ind_dim, constraint.dimension_type))
+    elif isinstance(space_dim, Integer):
         if not constraint.dimension_type == 'integer':
-            raise TypeError('Constraint for integer dimension {} must be of dimension_type integer. Got {}'.format(ind_dim,constraint.dimension_type))
-    elif isinstance(space_dim,Categorical):
+            raise TypeError('Constraint for integer dimension {} must be of dimension_type integer. Got {}'.format(ind_dim, constraint.dimension_type))
+    elif isinstance(space_dim, Categorical):
         if not constraint.dimension_type == 'categorical':
-            raise TypeError('Constraint for categorical dimension {} must be of dimension_type categorical. Got {}'.format(ind_dim,constraint.dimension_type))
+            raise TypeError('Constraint for categorical dimension {} must be of dimension_type categorical. Got {}'.format(ind_dim, constraint.dimension_type))
     else:
         raise TypeError('Can not find valid dimension for' + str(space_dim))
 
-def check_bounds(dim,bounds):
+
+def check_bounds(dim, bounds):
     """ Checks if bounds are included in the dimension.
         Throws errors otherwise.
 
@@ -598,16 +656,17 @@ def check_bounds(dim,bounds):
         """
 
     # Real or integer dimensions.
-    if isinstance(dim,Real) or isinstance(dim,Integer):
+    if isinstance(dim, Real) or isinstance(dim, Integer):
         for value in bounds:
             if value < dim.low or value > dim.high:
-                raise ValueError('Bounds {} exceeds bounds of space {}'.format(bounds,[dim.low,dim.high]))
-    else: # Categorical dimensions.
+                raise ValueError('Bounds {} exceeds bounds of space {}'.format(bounds, [dim.low, dim.high]))
+    else:  # Categorical dimensions.
         for value in bounds:
             if value not in dim.categories:
-                raise ValueError('Categorical value {} is not in space with categories {}'.format(value,dim.categories))
+                raise ValueError('Categorical value {} is not in space with categories {}'.format(value, dim.categories))
 
-def check_value(dim,value):
+
+def check_value(dim, value):
     """ Checks if value are included in the bounds of the dimension.
         Throws errors otherwise.
 
@@ -621,21 +680,19 @@ def check_value(dim,value):
         """
 
     # Real or integer dimension
-    if isinstance(dim,Real) or isinstance(dim,Integer):
+    if isinstance(dim, Real) or isinstance(dim, Integer):
         if value < dim.low or value > dim.high:
-            raise ValueError('Value {} exceeds bounds of space {}'.format(value,[dim.low,dim.high]))
-    else: # Categorical dimension.
+            raise ValueError('Value {} exceeds bounds of space {}'.format(value, [dim.low, dim.high]))
+    else:  # Categorical dimension.
         if value not in dim.categories:
-            raise ValueError('Categorical value {} is not in space with categoreis {}'.format(value,dim.categories))
+            raise ValueError('Categorical value {} is not in space with categoreis {}'.format(value, dim.categories))
+
 
 def check_is_constraint(constraint):
     ''' Checks if constraint is a valid constraint type. Throws error otherwise.
     Types can be Single, Inclusive, Exclusive, Sum and Conditional'''
 
     if not (isinstance(constraint, Single) or isinstance(constraint, Inclusive)
-        or isinstance(constraint, Exclusive) or isinstance(constraint, Sum)
-        or isinstance(constraint, Conditional)):
+            or isinstance(constraint, Exclusive) or isinstance(constraint, Sum)
+            or isinstance(constraint, Conditional)):
         raise TypeError('Constraint must be of type Inclusive, Exlusive, Single, Sum or Conditional. Got {}'.format(type(constraint)))
-
-
-    
\ No newline at end of file
